#!/usr/bin/env python
"""
NAME:
    tabbedwriter.py  

SYNOPSIS:
    import tabbedwriter
    wr=tabbedwriter.TabbedWriter(myfile)
    
DESCRIPTION:
    Inheritable (mixin) functionality for tab-indented
    writing.  Normally for indentable files, e.g.:
    Indents are 4 space chars by default.

OPTIONS:
    -h,--help        this message
    -v,--version     version
    -d,--debug       turn on debug messages

EXAMPLES:
    import tabbedwriter
    myfile=open('myfile.txt','w')
    tabbed_file=tabbedwriter.Tabbedwriter(myfile)
    
    def my_output(self,wr):
        out=wr.write;indent=wr.indent;undent=wr.undent
        out("Hello")
        indent()
        out("indented")
        undent()
        out("undented")
        out("start a line",nl=0)
        out("...and complete it",pad=0)
        
    myoutput(tabbed_file)

# tabbedwriter.py 
#    Copyright (C) 2001,2004  Harry George hgg9140@seanet.com
#    http://www.seanet.com/~hgg9140
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


"""
#============================
import sys,getopt

#===globals======================
modname="tabbedwriter"
__version__="0.1"

#--option args--
debug_p=0
#opt_b=None  #string arg, default is undefined

#---positional args, default is empty---
pargs=[]    

#---other---

#===utilities====================
def msg(txt):
    sys.stdout.write(txt)
    sys.stdout.flush()

def debug(ftn,txt):
    if debug_p:
        sys.stdout.write("%s.%s:%s\n" % (modname,ftn,txt))
        sys.stdout.flush()

def fatal(ftn,txt):
    msg="%s.%s:FATAL:%s\n" % (modname,ftn,txt)
    raise SystemExit, msg
 
def usage():
    print __doc__
    
#================================
class TabbedWriter:
    #--------------------------
    def __init__(self,writer=sys.stdout,tabsize=4):
        self.writer=writer
        self.tabsize=0 #spaces per single indent
        self.tabs=0    #how many indents
        self.pad1=''   #one indent-worth of pad
        self.pad=''    #pad = total indent = tabs*pad1
        
        #---initialize tabsize and pads---
        self.set_tabsize(tabsize)
        
    #--------------------------
    def set_tabsize(self,n=4):
        self.tabsize=n
        self.pad1=' '*self.tabsize
        self.pad=self.tabs*self.pad1
    #--------------------------
    def write(self,txt,pad=1,nl=1):
        wr=self.writer.write
        if pad:
            wr(self.pad)
        wr(txt)
        if nl:
            wr('\n')
    #--------------------------
    def indent(self):
        self.tabs=self.tabs+1
        self.pad=self.pad1*self.tabs
    #--------------------------
    def undent(self):
        if self.tabs>0:
            self.tabs=self.tabs-1
        self.pad=self.pad1*self.tabs

    #---------------------------
    def close(self):
        self.writer.close()
#==============================
default_wr=TabbedWriter(sys.stdout)

#=============================
def main(args):
    pass
    
#-------------------------
if __name__ == '__main__':
    ftn = "main"
    opts,pargs=getopt.getopt(sys.argv[1:],'hvd',
                 ['help','version','debug',
                  'bb='])
    for opt in opts:
        if opt[0]=='-h' or opt[0]=='--help':
            print modname+": version="+__version__
            usage()
            sys.exit(0)
        elif opt[0]=='-v' or opt[0]=='--version':
            print modname+": version="+__version__
            sys.exit(0)
        elif opt[0]=='-d' or opt[0]=='--debug':
            debug_p=1
        elif opt[0]=='--bb':
            opt_b=opt[1]

    #---make the object and run it---
    main(pargs)

#===Revision Log===
#Created by mkpythonproj:
#2001-09-23  Harry George  
#

#$Log: tabbedwriter.py$
