#!/usr/bin/env python
"""
NAME:
    basic_tests.py  

SYNOPSIS:
    basic_tests.py

DESCRIPTION:
    Run basic tests

OPTIONS:
    -h,--help        this message
    -v,--version     version

#Copyright (C) 2004  Harry George hgg9140@seanet.com
#http://www.seanet.com/~hgg9140
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""
#===imports======================
import sys,os,getopt,time,string,filecmp
from cStringIO import StringIO
import unittest

sys.path.insert(0,"..")
import tabbedwriter

#===globals======================
modname="basic_tests"
__version__="0.1"

#--option args--
debug_p=1  #hardcoded to bypass unittest

#---positional args, default is empty---
#---other----------------

#===utilities====================
def debug(ftn,txt):
    sys.stdout.write("%s.%s:%s\n" % (modname,ftn,txt))
    sys.stdout.flush()

def fatal(ftn,txt):
    msg="%s.%s:FATAL:%s\n" % (modname,ftn,txt)
    raise SystemExit, msg
 
def usage():
    print __doc__

#====================================
class BasicTestCase(unittest.TestCase):
    #------------------------
    def setUp(self):
        self.olddir=os.getcwd()
    #------------------------
    def tearDown(self):
        os.chdir(self.olddir)
    #------------------------
    def mkfiles(self,ftn):
        self.oraclename='testdata/oracle_%s.txt' % ftn
        self.testname='testdata/test_%s.txt' % ftn
        testfile=open(self.testname,'w')
        self.wr=tabbedwriter.TabbedWriter(writer=testfile)
        return self.wr
        
    #------------------------
    def check(self,ftn):
        self.wr.close()
        result=filecmp.cmp(self.oraclename,self.testname)
        self.failIf(result==0)
    #------------------------
    # Cases
    #------------------------
    def testindents(self):
        ftn="indents"
        wr=self.mkfiles(ftn)
        out=wr.write;indent=wr.indent;undent=wr.undent
        out("Hello")
        indent()
        out("indented")
        undent()
        out("undented")        
        self.check(ftn)
    #------------------------
    def testnewlines(self):
        ftn="newlines"
        wr=self.mkfiles(ftn)
        out=wr.write;indent=wr.indent;undent=wr.undent
        out("Hello")
        indent()
        out("indented")
        for i in range(100):
            if (i % 10) == 0:
                out('')
                out("%2.2i " % i, nl=0)
            else:
                out("%2.2i " % i, pad=0, nl=0)
        out('')
        undent()
        out("undented")        
        self.check(ftn)
    #------------------------
    def testtabsize(self):
        ftn="tabsize"
        wr=self.mkfiles(ftn)
        wr.set_tabsize(2)
        out=wr.write;indent=wr.indent;undent=wr.undent
        out("Hello")
        indent()
        out("indented")
        undent()
        out("undented")        
        self.check(ftn)

#=====================================
def suite():
    suite1 = unittest.TestSuite()
    cases=['indents',
           'newlines',
           'tabsize',
           ]
    
    for c in cases:
        suite1.addTest(BasicTestCase("test%s" % c))
    return suite1

#=============================
def main():
    unittest.main(defaultTest='suite')
    
#-------------------------
if __name__ == '__main__':
    ftn = "main"
    opts,pargs=getopt.getopt(sys.argv[1:],'hv',
                 ['help','version'])
    for opt in opts:
        if opt[0]=='-h' or opt[0]=='--help':
            print modname+": version="+__version__
            usage()
            sys.exit(0)
        elif opt[0]=='-v' or opt[0]=='--version':
            print modname+": version="+__version__
            sys.exit(0)

    #---make the object and run it---
    main()
